@@ -1,6 +1,14 @@
 #coding: utf-8
 from django.contrib import admin
-from assist.models import AssistAuthResult
+from django import forms
+from assist.models import AssistAuthResult, AssistResultChange
+
+class AssistResultChangeInline(admin.TabularInline):
+    model = AssistResultChange
+    extra = 0
+
+class AssistResultChangeAdmin(admin.ModelAdmin):
+    list_display=['auth_result', 'changed_at', 'changes']
 
 class AssistAuthResultAdmin(admin.ModelAdmin):
     list_display = ['BillNumber', 'OrderNumber', 'Date', 'Total', 'Status',
@@ -9,5 +17,7 @@ class AssistAuthResultAdmin(admin.ModelAdmin):
     date_hierarchy = 'Date'
     search_fields = ['OrderNumber', 'BillNumber']
     search_fields_verbose = [u'Номер заказа', u'Номер платежа']
+    inlines = [AssistResultChangeInline]
 
-admin.site.register(AssistAuthResult, AssistAuthResultAdmin)
\ No newline at end of file
+admin.site.register(AssistAuthResult, AssistAuthResultAdmin)
+admin.site.register(AssistResultChange, AssistResultChangeAdmin)
\ No newline at end of file
